@@ -53,9 +53,10 @@ pub trait SyscallStubs: Sync + Send {
     /// # Safety
     unsafe fn sol_memcpy(&self, dst: *mut u8, src: *const u8, n: usize) {
         // cannot be overlapping
-        if dst as usize + n > src as usize && src as usize > dst as usize {
-            panic!("memcpy does not support overlapping regions");
-        }
+        assert!(
+            !(dst as usize + n > src as usize && src as usize > dst as usize),
+            "memcpy does not support overlapping regions"
+        );
         std::ptr::copy_nonoverlapping(src, dst, n as usize);
     }
     /// # Safety
@@ -132,8 +133,8 @@ pub(crate) fn sol_get_epoch_schedule_sysvar(var_addr: *mut u8) -> u64 {
         .sol_get_epoch_schedule_sysvar(var_addr)
 }
 
-pub(crate) fn sol_get_fees_sysvar(var_addr: *mut u8) -> u64 {
-    SYSCALL_STUBS.read().unwrap().sol_get_fees_sysvar(var_addr)
+pub(crate) fn sol_get_fees_sysvar(_var_addr: *mut u8) -> u64 {
+    UNSUPPORTED_SYSVAR
 }
 
 pub(crate) fn sol_get_rent_sysvar(var_addr: *mut u8) -> u64 {
