@@ -1,3 +1,4 @@
+#[allow(deprecated)]
 use {
     crate::{
         decode_error::DecodeError,
@@ -143,8 +144,8 @@ pub enum SystemInstruction {
     /// Create a new account
     ///
     /// # Account references
-    ///   0. [WRITE, SIGNER] Funding account
-    ///   1. [WRITE, SIGNER] New account
+    ///   0. `[WRITE, SIGNER]` Funding account
+    ///   1. `[WRITE, SIGNER]` New account
     CreateAccount {
         /// Number of lamports to transfer to the new account
         lamports: u64,
@@ -159,7 +160,7 @@ pub enum SystemInstruction {
     /// Assign account to a program
     ///
     /// # Account references
-    ///   0. [WRITE, SIGNER] Assigned account public key
+    ///   0. `[WRITE, SIGNER]` Assigned account public key
     Assign {
         /// Owner program account
         owner: Pubkey,
@@ -168,16 +169,16 @@ pub enum SystemInstruction {
     /// Transfer lamports
     ///
     /// # Account references
-    ///   0. [WRITE, SIGNER] Funding account
-    ///   1. [WRITE] Recipient account
+    ///   0. `[WRITE, SIGNER]` Funding account
+    ///   1. `[WRITE]` Recipient account
     Transfer { lamports: u64 },
 
     /// Create a new account at an address derived from a base pubkey and a seed
     ///
     /// # Account references
-    ///   0. [WRITE, SIGNER] Funding account
-    ///   1. [WRITE] Created account
-    ///   2. [SIGNER] (optional) Base account; the account matching the base Pubkey below must be
+    ///   0. `[WRITE, SIGNER]` Funding account
+    ///   1. `[WRITE]` Created account
+    ///   2. `[SIGNER]` (optional) Base account; the account matching the base Pubkey below must be
     ///                          provided as a signer, but may be the same as the funding account
     ///                          and provided as account 0
     CreateAccountWithSeed {
@@ -200,30 +201,30 @@ pub enum SystemInstruction {
     /// Consumes a stored nonce, replacing it with a successor
     ///
     /// # Account references
-    ///   0. [WRITE] Nonce account
-    ///   1. [] RecentBlockhashes sysvar
-    ///   2. [SIGNER] Nonce authority
+    ///   0. `[WRITE]` Nonce account
+    ///   1. `[]` RecentBlockhashes sysvar
+    ///   2. `[SIGNER]` Nonce authority
     AdvanceNonceAccount,
 
     /// Withdraw funds from a nonce account
     ///
     /// # Account references
-    ///   0. [WRITE] Nonce account
-    ///   1. [WRITE] Recipient account
-    ///   2. [] RecentBlockhashes sysvar
-    ///   3. [] Rent sysvar
-    ///   4. [SIGNER] Nonce authority
+    ///   0. `[WRITE]` Nonce account
+    ///   1. `[WRITE]` Recipient account
+    ///   2. `[]` RecentBlockhashes sysvar
+    ///   3. `[]` Rent sysvar
+    ///   4. `[SIGNER]` Nonce authority
     ///
     /// The `u64` parameter is the lamports to withdraw, which must leave the
     /// account balance above the rent exempt reserve or at zero.
     WithdrawNonceAccount(u64),
 
-    /// Drive state of Uninitalized nonce account to Initialized, setting the nonce value
+    /// Drive state of Uninitialized nonce account to Initialized, setting the nonce value
     ///
     /// # Account references
-    ///   0. [WRITE] Nonce account
-    ///   1. [] RecentBlockhashes sysvar
-    ///   2. [] Rent sysvar
+    ///   0. `[WRITE]` Nonce account
+    ///   1. `[]` RecentBlockhashes sysvar
+    ///   2. `[]` Rent sysvar
     ///
     /// The `Pubkey` parameter specifies the entity authorized to execute nonce
     /// instruction on the account
@@ -235,8 +236,8 @@ pub enum SystemInstruction {
     /// Change the entity authorized to execute nonce instructions on the account
     ///
     /// # Account references
-    ///   0. [WRITE] Nonce account
-    ///   1. [SIGNER] Nonce authority
+    ///   0. `[WRITE]` Nonce account
+    ///   1. `[SIGNER]` Nonce authority
     ///
     /// The `Pubkey` parameter identifies the entity to authorize
     AuthorizeNonceAccount(Pubkey),
@@ -244,7 +245,7 @@ pub enum SystemInstruction {
     /// Allocate space in a (possibly new) account without funding
     ///
     /// # Account references
-    ///   0. [WRITE, SIGNER] New account
+    ///   0. `[WRITE, SIGNER]` New account
     Allocate {
         /// Number of bytes of memory to allocate
         space: u64,
@@ -254,8 +255,8 @@ pub enum SystemInstruction {
     ///    derived from a base public key and a seed
     ///
     /// # Account references
-    ///   0. [WRITE] Allocated account
-    ///   1. [SIGNER] Base account
+    ///   0. `[WRITE]` Allocated account
+    ///   1. `[SIGNER]` Base account
     AllocateWithSeed {
         /// Base public key
         base: Pubkey,
@@ -273,8 +274,8 @@ pub enum SystemInstruction {
     /// Assign account to a program based on a seed
     ///
     /// # Account references
-    ///   0. [WRITE] Assigned account
-    ///   1. [SIGNER] Base account
+    ///   0. `[WRITE]` Assigned account
+    ///   1. `[SIGNER]` Base account
     AssignWithSeed {
         /// Base public key
         base: Pubkey,
@@ -289,9 +290,9 @@ pub enum SystemInstruction {
     /// Transfer lamports from a derived address
     ///
     /// # Account references
-    ///   0. [WRITE] Funding account
-    ///   1. [SIGNER] Base for funding account
-    ///   2. [WRITE] Recipient account
+    ///   0. `[WRITE]` Funding account
+    ///   1. `[SIGNER]` Base for funding account
+    ///   2. `[WRITE]` Recipient account
     TransferWithSeed {
         /// Amount to transfer
         lamports: u64,
@@ -485,6 +486,7 @@ pub fn create_nonce_account_with_seed(
             &SystemInstruction::InitializeNonceAccount(*authority),
             vec![
                 AccountMeta::new(*nonce_pubkey, false),
+                #[allow(deprecated)]
                 AccountMeta::new_readonly(recent_blockhashes::id(), false),
                 AccountMeta::new_readonly(rent::id(), false),
             ],
@@ -511,6 +513,7 @@ pub fn create_nonce_account(
             &SystemInstruction::InitializeNonceAccount(*authority),
             vec![
                 AccountMeta::new(*nonce_pubkey, false),
+                #[allow(deprecated)]
                 AccountMeta::new_readonly(recent_blockhashes::id(), false),
                 AccountMeta::new_readonly(rent::id(), false),
             ],
@@ -521,6 +524,7 @@ pub fn create_nonce_account(
 pub fn advance_nonce_account(nonce_pubkey: &Pubkey, authorized_pubkey: &Pubkey) -> Instruction {
     let account_metas = vec![
         AccountMeta::new(*nonce_pubkey, false),
+        #[allow(deprecated)]
         AccountMeta::new_readonly(recent_blockhashes::id(), false),
         AccountMeta::new_readonly(*authorized_pubkey, true),
     ];
@@ -540,6 +544,7 @@ pub fn withdraw_nonce_account(
     let account_metas = vec![
         AccountMeta::new(*nonce_pubkey, false),
         AccountMeta::new(*to_pubkey, false),
+        #[allow(deprecated)]
         AccountMeta::new_readonly(recent_blockhashes::id(), false),
         AccountMeta::new_readonly(rent::id(), false),
         AccountMeta::new_readonly(*authorized_pubkey, true),
